## Replicate results in Section 6. This includes Figure 6.

## Call: "Rscript empirical_application.R TRUE" from current directory. To only
## replicate the tables only, call "Rscript empirical_application.R FALSE"
fig <- commandArgs(trailingOnly = TRUE)[1]


tol <- .Machine$double.eps^0.75
s <- !is.na(RDHonest::headst$mortHS)
mort <- RDHonest::RDData(RDHonest::headst[s, c("mortHS", "povrate60")],
                         cutoff=0)

## Figure 5
if (fig) {
    tikzDevice::tikz("output/figures/figure_5.tex", width=4.2,
                     height=3, verbose=FALSE)
    print(RDHonest::plot_RDscatter(mort, avg=25,
                                   xlab="Poverty rate minus 59.1984",
                                   ylab="Mortality rate"))
    grDevices::dev.off()
}

sink("output/tables/empirical_application.txt")
cat("\nNumbers in the text:")

## For what M are these MSE optimal? fs=finite-sample RMSE, a=asymptotic RMSE
source("R/rd_empirical_analysis.R")
ru <- HolderAnalysis(mort, "uniform", bws=c(9, 18, 36), se.method="nn")

## Add ROT Bandwidth
Mh <- RDHonest::NPR_MROT.fit(mort)
r <- RDHonest::NPRHonest.fit(mort, M=Mh, opt.criterion="MSE", kern="uniform")
ru <- rbind(ru, data.frame(as.data.frame(r[-c(2, 12)]), M=Mh,
                           cvb=RDHonest::CVb(r$maxbias/r$sd)$cv))
## P-value.
pvalue <- function(t, b) {
    sapply(seq_along(t), function(j)
    uniroot(function(alp) abs(t[j])-RDHonest::CVb(b[j], alp)$cv,
            c(1e-100, 1-1e-6))$root)
}
ru <- data.frame(ru, pvalue=pvalue(ru$estimate/ru$sd, ru$maxbias/ru$sd))
rownames(ru) <- NULL
tbl <- function(ru) knitr::kable(data.frame(cil=ru$estimate-ru$hl,
                                            cir=ru$estimate+ru$hl,
                               ru[, c(1, 3, 8, 11, 12, 13)]),
                               digits=c(3, 3, 2, 2, 1, 4, 3, 3))
cat("\nUniform kernel:")
print(tbl(ru))

## 3. Use triangular kernel, slightly higher efficiency
rt <- HolderAnalysis(mort, "triangular", Ms=ru$M, se.method="nn")
rt <- data.frame(rt, pvalue=pvalue(rt$estimate/rt$sd, rt$maxbias/rt$sd))
rownames(rt) <- NULL
cat("\nTriangular kernel:")
print(tbl(rt))
cat("\nCIs tighter by", rt$hl/ru$hl, "\n")
sink()
