## Replicate results in Section 5, and Appendix F. This includes Table 6, and
## S3-S10

## Call: "Rscript simulation.R nsim cores TRUE" from current directory, where
## nsim is the number of simulations, and cores is the number of cores to
## parallelize the computation. To not replicate Figure 4, call "Rscript
## simulation.R nsim cores FALSE"

args <- commandArgs(trailingOnly = TRUE)
nsim <- as.numeric(args[1])
cores <- as.numeric(args[2])
fig <- args[3]

## 9 designs for distro of X and epsilon
des <- rbind(data.frame(k=Inf,
                        expand.grid(unif=c(1, 0), eps=c(1L, 2L, 3L)),
                        sigma=1/2),
             c(40, 1, 1, 1/2), c(Inf, 1, 1, 1/4))
## 5 conditional means per design
p1 <- rbind(c(0.25, 1.00, 1.05, NA), c(0.20, 0.50, 0.65, NA),
            c(-0.2,  0.2,  0.4, 0.7))
par <- cbind(p1[rep(seq_len(nrow(p1)), nrow(des)), ],
             des[rep(seq_len(nrow(des)), each=nrow(p1)), ])
colnames(par)[(1:4)] <- c("b1", "b2", "b3", "b4")
rownames(par) <- NULL
n <- 500

source("R/optimal_t.R")
source("R/lp_simulation.R")

## Figure 4
if (fig) {
    leg <- c("Design 1", "Design 2", "Design 3")
    f4 <- LPPlotDesign(M=2, par[1:3, ], legend=leg) +
        ggplot2::xlim(c(-1.2, 1)) + ggplot2::scale_color_grey(start=0, end=0)

    tikzDevice::tikz(paste0("output/figures/figure_4.tex"),
                     width=5.5, height=3.5, verbose=FALSE)
    print(f4)
    grDevices::dev.off()
}

DoSim <- function(M)
    LPSimulate(n=n, M=M, par, nsim,
               eff.row=if (M==6) 11 else 9, cores, Mh=c(2, 6))

filename <- paste0("output/data/LPSimResults-", nsim, "-", nrow(par), ".RData")
sink(paste0("output/tables/LPSimResults-", nsim, "-", nrow(par), ".txt"))
if (!file.exists(filename)) {
    s1 <- DoSim(M=2)
    s2 <- DoSim(M=6)
    save(s1, s2, file=filename)
} else {
    load(filename)
}

## Rejection rate to coverage
s1$r <- 100*(1-s1$r)
s2$r <- 100*(1-s2$r)

## Report only those rows which go to the paper, drop half-length
rw <- c(2, 3, 5, 10, 12, 14, 7, 4, 9, 11, 13)
rw1 <- rep(0:(nrow(par)-1), each=length(rw)) * (nrow(s1)/nrow(par)) + rw
dropcol <- colnames(s1) %in% c("hl", "sdbw", "iqrbw", "medbw")
t0 <- cbind(s1[rw1, !dropcol], s2[rw1, !dropcol][, -(1:10)])

digs <- c(2, 2, 2, 2, 0, 0, 0, 1, 0, 0, rep(c(3, 3, 2, 1, 2), 2))
cat("\nMain tables")
print(knitr::kable(t0, digits=digs, row.names=FALSE))
sink()
