## Replicate results in Sections 2--4, and Appendix D. This includes Tables 1,
## 2, 3, 4, 5, S1, S2, and Figures 1, 2, 3, S1, S2

## Call: "Rscript theory.R TRUE" from current directory. To only replicate the
## tables only, call "Rscript theory.R FALSE"
fig <- commandArgs(trailingOnly = TRUE)[1]

## Load helper functions
tol <- .Machine$double.eps^0.75
source("R/sy_kernel.R")
source("R/holder_kernel.R")
SYKernelB <- lapply(1:4, function(j) SYKernel(j, boundary=TRUE,
                                              recompute=TRUE)[2:4])
SYKernelI <- lapply(1:4, function(j) SYKernel(j, boundary=FALSE,
                                              recompute=TRUE)[2:4])
source("R/kernel_efficiency.R")
source("R/optimal_t.R")

sink("output/tables/theory.txt")

## Table 1
B <- c(0, sqrt(1/6), 1/2, sqrt(3/2-1), 1, 1.5, 2)
t1 <- cbind(c("", "6/7", "4/5", "2/3", "1/2", "", ""),
            RDHonest::CVb(B, 0.01)[, c(1, 3)],
            RDHonest::CVb(B, 0.05)$cv, RDHonest::CVb(B, 0.1)$cv)
names(t1) <- c("r", "t", "alpha=0.01", "alpha=0.05", "alpha=0.1")

cat("\nTable 1:")
print(knitr::kable(t1, digits=3))

## Tables 2-5, S1, S2
rt <- tbl_KerEfficiency("T")
rh <- tbl_KerEfficiency("H")
t2 <- cbind(rt$boundary[, c(1:2, 7:9)], rt$interior[, 7:9])
t3 <- cbind(rh$boundary[, c(1:2, 7:9)], rh$interior[, 7:9])
ts1 <- cbind(rt$boundary[, 1:6], rh$boundary[, 4:6])
ts2 <- cbind(rt$interior[, 1:6], rh$interior[, 4:6])
t4 <- tbl_HolderGains()

rh <- tbl_AltCIEfficiency("H", what="CCT")
rt <- tbl_AltCIEfficiency("T", what="CCT")
t5 <- cbind(rt, rh[, -(1:2)])

cat("\nTable 2:")
print(knitr::kable(t2, digits=4))
cat("\nTable 3:")
print(knitr::kable(t3, digits=4))
cat("\nTable S1:")
print(knitr::kable(ts1, digits=4))
cat("\nTable S2:")
print(knitr::kable(ts2, digits=4))
cat("\nTable 4")
print(knitr::kable(t4, digits=4))
cat("\nTable 5")
print(knitr::kable(t5, digits=c(0, 0, 2, 3, 3, 2, 3, 3)))

cat("\nClaims in text, Section 2:",
    "\nLength penalty of CI at RMSE bw for r=4/5, alpha=0.05:",
    1/BWEfficiency(r=4/5, beta=0.5, alpha=0.05)[2, 6], "\n")
sink()

## Figures 1, 2, 3, S1, S2
if (fig) {
    r <- plot_BWEfficiency()

    figfile <- "output/figures/"
    f1 <- r$p1+ggplot2::scale_color_grey(start=0, end=0)
    f2 <- r$p2+ggplot2::scale_color_grey(start=0, end=0)
    f3 <- r$p3+ggplot2::scale_color_grey(start=0, end=0)
    fs1a <- plot_SYKernel(p=2:4, FALSE) +
        ggplot2::theme(strip.text.y=ggplot2::element_blank())
    fs1b <- plot_SYKernel(p=2:4, TRUE) + ggplot2::ylab("")

    fs2a <- plot_HolKernel(FALSE)
    fs2b <- plot_HolKernel(TRUE) + ggplot2::ylab("")

    tikzDevice::tikz(paste0(figfile, "figure_1.tex"), width=4.5,
                     height=3, verbose=FALSE)
    print(f1)
    grDevices::dev.off()

    tikzDevice::tikz(paste0(figfile, "figure_2.tex"), width=4.5,
                     height=3, verbose=FALSE)
    print(f2)
    grDevices::dev.off()

    tikzDevice::tikz(paste0(figfile, "figure_3.tex"), width=4.5,
                     height=3, verbose=FALSE)
    print(f3)
    grDevices::dev.off()

    tikzDevice::tikz(paste0(figfile, "figure_s1a.tex"), width=3,
                     height=6.2, verbose=FALSE)
    print(fs1a)
    grDevices::dev.off()

    tikzDevice::tikz(paste0(figfile, "figure_s1b.tex"), width=3,
                     height=6.2, verbose=FALSE)
    print(fs1b)
    grDevices::dev.off()

    tikzDevice::tikz(paste0(figfile, "figure_s2a.tex"), width=3,
                     height=3.2, verbose=FALSE)
    print(fs2a)
    grDevices::dev.off()

    tikzDevice::tikz(paste0(figfile, "figure_s2b.tex"), width=3,
                     height=3.2, verbose=FALSE)
    print(fs2b)
    grDevices::dev.off()
}
